@@ -2,6 +2,7 @@ from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext as _
+from guardian.admin import GuardedModelAdmin
 
 from userena.models import UserenaSignup
 from userena.utils import get_profile_model
@@ -10,7 +11,7 @@ class UserenaSignupInline(admin.StackedInline):
     model = UserenaSignup
     max_num = 1
 
-class UserenaAdmin(UserAdmin):
+class UserenaAdmin(UserAdmin, GuardedModelAdmin):
     inlines = [UserenaSignupInline, ]
     list_display = ('username', 'email', 'first_name', 'last_name',
                     'is_staff', 'date_joined')
